Enum pallet_remote_asset_manager::pallet::Call [−][src]
pub enum Call<T: Config> {
send_bond {
asset: T::AssetId,
controller: <<T as Config>::Lookup as StaticLookup>::Source,
value: T::Balance,
payee: RewardDestination<<T as Config>::AccountId>,
},
send_add_proxy {
asset: T::AssetId,
proxy_type: ProxyType,
delegate: Option<<T as Config>::AccountId>,
},
update_staking_weights {
asset: T::AssetId,
weights: StakingWeights,
},
update_proxy_weights {
asset: T::AssetId,
weights: ProxyWeights,
},
freeze {
asset: T::AssetId,
},
thaw {
asset: T::AssetId,
},
set_xcm_dest_weight {
xcm_dest_weight: Weight,
},
enable_statemint_xcm {},
disable_statemint_xcm {},
set_statemint_config {
config: StatemintConfig,
},
transfer_to_statemint {
amount: T::Balance,
},
// some variants omitted
}Expand description
Contains one variant per dispatchable that can be called by an extrinsic.
Variants
Send a pallet_staking bond call to the location of the asset.
This will encode the bond call accordingly and dispatch to the
location of the given asset. Limited to the council origin.
Fields of send_bond
asset: T::AssetIdcontroller: <<T as Config>::Lookup as StaticLookup>::Sourcevalue: T::Balancepayee: RewardDestination<<T as Config>::AccountId>Transacts a pallet_proxy::Call::add_proxy call to add a proxy on
behalf of the PINT parachain’s account on the target chain.
Limited to the council origin
Fields of send_add_proxy
Updates the configured staking weights for the given asset.
Callable by the admin origin
Fields of update_staking_weights
asset: T::AssetIdweights: StakingWeightsUpdates the configured proxy weights for the given asset.
Callable by the admin origin
Fields of update_proxy_weights
asset: T::AssetIdweights: ProxyWeightsDisallow further remote transfers and halt remote staking.
asset_id: The identifier of the asset to be frozen.
Callable by the admin origin.
Emits Frozen.
Weight: O(1)
Fields of freeze
asset: T::AssetIdAllow remote transfers and enable remote staking again.
asset_id: The identifier of the asset to be frozen.
Callable by the admin origin
Emits Thawed.
Weight: O(1)
Fields of thaw
asset: T::AssetIdSets the xcm_dest_weight for XCM transfers.
Callable by the admin origin
Parameters:
xcm_dest_weight: The new weight for XCM transfers.
Fields of set_xcm_dest_weight
xcm_dest_weight: WeightEnables XCM transactions for the statemint parachain, if configured.
This is a noop if it’s already enabled Callable by the admin origin
Fields of enable_statemint_xcm
Disables XCM transactions for the statemint parachain, if configured.
This is a noop if it’s already disabled Callable by the admin origin
Fields of disable_statemint_xcm
Sets the statemint config.
Callable by the admin origin
NOTE It is assumed that the PINT parachain’s local account on
the statemint parachain (sibling account:
polkadot_parachain::primitives::Sibling) has the permission to
modify the statemint PINT asset.
Fields of set_statemint_config
config: StatemintConfigAttempts to transfer the given amount of index token to statemint.
This is executed as reserve based transfer, the given amount is transferred from the sender’s balance to the account designated for the Statemint parachain. This amount is then send via XCM into the caller’s account on the statemint parachain.
Fields of transfer_to_statemint
amount: T::BalanceImplementations
pub fn new_call_variant_send_bond(
asset: T::AssetId,
controller: <<T as Config>::Lookup as StaticLookup>::Source,
value: T::Balance,
payee: RewardDestination<<T as Config>::AccountId>
) -> Self
pub fn new_call_variant_send_bond(
asset: T::AssetId,
controller: <<T as Config>::Lookup as StaticLookup>::Source,
value: T::Balance,
payee: RewardDestination<<T as Config>::AccountId>
) -> Self
Create a call with the variant send_bond.
Create a call with the variant send_add_proxy.
pub fn new_call_variant_update_staking_weights(
asset: T::AssetId,
weights: StakingWeights
) -> Self
pub fn new_call_variant_update_staking_weights(
asset: T::AssetId,
weights: StakingWeights
) -> Self
Create a call with the variant update_staking_weights.
pub fn new_call_variant_update_proxy_weights(
asset: T::AssetId,
weights: ProxyWeights
) -> Self
pub fn new_call_variant_update_proxy_weights(
asset: T::AssetId,
weights: ProxyWeights
) -> Self
Create a call with the variant update_proxy_weights.
Create a call with the variant freeze.
Create a call with the variant thaw.
Create a call with the variant set_xcm_dest_weight.
Create a call with the variant enable_statemint_xcm.
Create a call with the variant disable_statemint_xcm.
Create a call with the variant set_statemint_config.
Create a call with the variant transfer_to_statemint.