Enum pallet_remote_asset_manager::pallet::Error [−][src]
pub enum Error<T> {
Show 22 variants
AlreadyProxy,
NoProxyFound,
NotEncodableForLocation,
NoPalletConfigFound,
NoStatemintConfigFound,
StatemintDisabled,
FailedToSendBondXcm,
FailedToSendBondExtraXcm,
FailedToSendUnbondXcm,
FailedToSendWithdrawUnbondedXcm,
FailedToSendAddProxyXcm,
FailedToSendRemoveProxyXcm,
AlreadyBonded,
NotBonded,
NoControllerPermission,
NoMoreUnbondingChunks,
NothingToWithdraw,
InsufficientBond,
InusufficientStash,
InvalidAssetChainLocation,
NotCrossChainTransferableCurrency,
MinimumStatemintTransfer,
// some variants omitted
}Expand description
Custom dispatch errors of this pallet.
Variants
Thrown when the proxy type was already set.
Thrown when the requested proxy type to removed was not added before.
Thrown when the requested cross-chain call could not be encoded for the given location.
Thrown when no config was found for the requested location
Thrown when no config was found for statemint
Thrown when statemint support is currently disabled
Thrown when sending an Xcm pallet_staking::bond failed
Thrown when sending an Xcm pallet_staking::bond_extra failed
Thrown when sending an Xcm pallet_staking::unbond failed
Thrown when sending an Xcm pallet_staking::withdraw_unbonded
failed
Thrown when sending an Xcm pallet_proxy::add_proxy failed
Thrown when sending an Xcm pallet_proxy::remove_proxy failed
PINT’s stash is already bonded.
PINT’s stash is not bonded yet with bond.
Thrown if the PINT parachain account is not allowed to executed pallet staking extrinsics that require controller origin
Thrown if the no more unbond chunks can be scheduled
Thrown if no funds are currently unbonded
Balance would fall below the minimum requirements for bond
Thrown if the balance of the PINT parachain account would fall below the minimum reserve balance
Thrown if liquid asset has invalid chain location
Currency is not cross-chain transferable.
Thrown if the given amount of PINT to send to statemint is too low
Implementations