Struct pallet_remote_asset_manager::types::AssetLedger [−][src]
pub struct AssetLedger<Balance> {
pub deposited: Balance,
pub pending_redemption: Balance,
}Expand description
Represents the different balances of an asset
Fields
deposited: BalanceThe real deposits contributed to the index
pending_redemption: Balancethe amount of the asset about to be withdrawn
Implementations
Cancel each balance out, after which at least 1 balance is zero.